==> moengagesdk-4.0.00-sources.jar: com/moengage/core/ActivityStartTask.java <==
package com.moengage.core;

import android.app.Activity;
import android.text.TextUtils;
import com.moe.pushlibrary.MoEHelper;
import com.moengage.core.analytics.AnalyticsHelper;
import com.moengage.core.executor.SDKTask;
import com.moengage.core.executor.TaskResult;
import java.util.Set;

/**
 * Logs activity start event
 * Service constant MSG_ACTIVITY_START
 *
 * @author Umang Chamaria
 */
class ActivityStartTask extends SDKTask {

  private static final String TAG = "ActivityStartTask";

  private Activity activity;

  ActivityStartTask(Activity activity) {
    super(activity.getApplicationContext());
    this.activity = activity;
  }

  @Override public TaskResult execute() {
    try {
      Logger.v(TAG + " started execution");
      String activityName = activity.getClass().getName();
      Logger.v("ActivityLifecycleStart : " + activityName + " started");
      // on app open
      if (MoEHelper.getInstance(context).isFirstScreen()) {
        // update session if required.
        AnalyticsHelper.getInstance(context).onAppOpen(activity);

        MoEUtils.trackActivityStates(MoEConstants.EVENT_ACTION_ACTIVITY_START, activityName,
            context);
        ConfigurationCache.getInstance().addScreenToSentList(activityName);
        // delete stale data, mainly expired campaigns.
        MoEDAO.getInstance(context).removeExpiredData();
        // check and update GAID if required.
        checkGoogleAdvertisementIDAndUpdate();
        // reset 1st screen state
        MoEHelper.getInstance(context).setFirstScreen(false);
      } else {
        trackActivityIfRequired(activityName);
      }
      taskResult.setIsSuccess(true);
      Logger.v(TAG + " completed execution");
    } catch (Exception e) {
      Logger.e(TAG + " execute() : Exception: ", e);
    }
    return taskResult;
  }

  @Override public String getTaskTag() {
    return TAG_ACTIVITY_START;
  }

  @Override public boolean isSynchronous() {
    return false;
  }

  private void checkGoogleAdvertisementIDAndUpdate() {
    ConfigurationProvider provider = ConfigurationProvider.getInstance(context);
    if (SdkConfig.getConfig().isGaidTrackingOptedOut) {
      Logger.f("ActivityStartTask : Opted out of GAID Collection");
      return;
    }

    String storedGAID = provider.getStoredGAID();
    int storedISLAT = provider.getStoredISLAT();
    AdvertisingIdClient.AdInfo adInfo = MoEUtils.getAdvertisementInfo(context);
    if (adInfo == null) return;
    //check if the google advertisement id has changed or not
    if (!TextUtils.isEmpty(adInfo.getId()) && (TextUtils.isEmpty(storedGAID) || (!adInfo.getId()
        .equals(storedGAID)))) {
      MoEHelper.getInstance(context).setUserAttribute(MoEConstants.ATTR_MOE_GAID,
          adInfo.getId());
      provider.storeGAID(adInfo.getId());
    }
    //check if the adTracking opt out has changed or not
    if (adInfo.isLimitAdTrackingEnabled() != storedISLAT) {
      MoEHelper.getInstance(context).setUserAttribute(MoEConstants.ATTR_IS_LAT,
          Integer.toString(adInfo.isLimitAdTrackingEnabled()));
      provider.storeISLAT(adInfo.isLimitAdTrackingEnabled());
    }
  }

  private boolean isActivityTracked(String activityName) {
    try {
      Set<String> trackedScreen = ConfigurationCache.getInstance().getSentScreenNames();
      return trackedScreen != null && trackedScreen.contains(activityName);
    } catch (Exception e) {
      Logger.f(TAG + " isActivityTracked() : ", e);
    }
    return false;
  }

  private void trackActivityIfRequired(String activityName){
    if (isActivityTracked(activityName)) return;
    if ( MoEDispatcher.getInstance(context)
        .getCoreEvaluator()
        .shouldTrackScreenName(activityName,
            SdkConfig.getConfig().activityTrackingOptOutList)) {
      MoEUtils.trackActivityStates(MoEConstants.EVENT_ACTION_ACTIVITY_START, activityName,
          context);
      ConfigurationCache.getInstance().addScreenToSentList(activityName);
    }
  }
}

==> moengagesdk-4.1.03-sources.jar: com/moengage/core/ActivityStartTask.java <==
/*
 * Copyright (c) 2014-2020 MoEngage Inc.
 *
 * All rights reserved.
 *
 *  Use of source code or binaries contained within MoEngage SDK is permitted only to enable use of the MoEngage platform by customers of MoEngage.
 *  Modification of source code and inclusion in mobile apps is explicitly allowed provided that all other conditions are met.
 *  Neither the name of MoEngage nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 *  Redistribution of source code or binaries is disallowed except with specific prior written permission. Any such redistribution must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.moengage.core;

import android.app.Activity;
import android.text.TextUtils;
import com.moe.pushlibrary.MoEHelper;
import com.moengage.core.analytics.AnalyticsHelper;
import com.moengage.core.executor.SDKTask;
import com.moengage.core.executor.TaskResult;
import java.util.Set;

/**
 * Logs activity start event
 * Service constant MSG_ACTIVITY_START
 *
 * @author Umang Chamaria
 */
class ActivityStartTask extends SDKTask {

  private static final String TAG = "ActivityStartTask";

  private Activity activity;

  ActivityStartTask(Activity activity) {
    super(activity.getApplicationContext());
    this.activity = activity;
  }

  @Override public TaskResult execute() {
    try {
      Logger.v(TAG + " started execution");
      String activityName = activity.getClass().getName();
      Logger.v("ActivityLifecycleStart : " + activityName + " started");
      // on app open
      if (MoEHelper.getInstance(context).isFirstScreen()) {
        // update session if required.
        AnalyticsHelper.getInstance(context).onAppOpen(activity);

        MoEUtils.trackActivityStates(MoEConstants.EVENT_ACTION_ACTIVITY_START, activityName,
            context);
        ConfigurationCache.getInstance().addScreenToSentList(activityName);
        // delete stale data, mainly expired campaigns.
        MoEDAO.getInstance(context).removeExpiredData();
        // check and update GAID if required.
        checkGoogleAdvertisementIDAndUpdate();
        // reset 1st screen state
        MoEHelper.getInstance(context).setFirstScreen(false);
      } else {
        trackActivityIfRequired(activityName);
      }
      taskResult.setIsSuccess(true);
      Logger.v(TAG + " completed execution");
    } catch (Exception e) {
      Logger.e(TAG + " execute() : Exception: ", e);
    }
    return taskResult;
  }

  @Override public String getTaskTag() {
    return TAG_ACTIVITY_START;
  }

  @Override public boolean isSynchronous() {
    return false;
  }

  private void checkGoogleAdvertisementIDAndUpdate() {
    ConfigurationProvider provider = ConfigurationProvider.getInstance(context);
    if (SdkConfig.getConfig().isGaidTrackingOptedOut) {
      Logger.e("ActivityStartTask : Opted out of GAID Collection");
      return;
    }

    String storedGAID = provider.getStoredGAID();
    int storedISLAT = provider.getStoredISLAT();
    AdvertisingIdClient.AdInfo adInfo = MoEUtils.getAdvertisementInfo(context);
    if (adInfo == null) return;
    //check if the google advertisement id has changed or not
    if (!TextUtils.isEmpty(adInfo.getId()) && (TextUtils.isEmpty(storedGAID) || (!adInfo.getId()
        .equals(storedGAID)))) {
      MoEHelper.getInstance(context).setUserAttribute(MoEConstants.ATTR_MOE_GAID,
          adInfo.getId());
      provider.storeGAID(adInfo.getId());
    }
    //check if the adTracking opt out has changed or not
    if (adInfo.isLimitAdTrackingEnabled() != storedISLAT) {
      MoEHelper.getInstance(context).setUserAttribute(MoEConstants.ATTR_IS_LAT,
          Integer.toString(adInfo.isLimitAdTrackingEnabled()));
      provider.storeISLAT(adInfo.isLimitAdTrackingEnabled());
    }
  }

  private boolean isActivityTracked(String activityName) {
    try {
      Set<String> trackedScreen = ConfigurationCache.getInstance().getSentScreenNames();
      return trackedScreen != null && trackedScreen.contains(activityName);
    } catch (Exception e) {
      Logger.e(TAG + " isActivityTracked() : ", e);
    }
    return false;
  }

  private void trackActivityIfRequired(String activityName){
    if (isActivityTracked(activityName)) return;
    if ( MoEDispatcher.getInstance(context)
        .getCoreEvaluator()
        .shouldTrackScreenName(activityName,
            SdkConfig.getConfig().activityTrackingOptOutList)) {
      MoEUtils.trackActivityStates(MoEConstants.EVENT_ACTION_ACTIVITY_START, activityName,
          context);
      ConfigurationCache.getInstance().addScreenToSentList(activityName);
    }
  }
}
